@@ -34,7 +34,7 @@ void AccessLogThread::do_work()
 	if (filename.empty()) {
 		logfp = nullptr;
 	} else {
-		logfp = fopen(filename.c_str(), "a+");
+		logfp = fopen(filename.c_str(), "a+e");
 		if (logfp == nullptr) {
 			log_perror(filename.c_str());
 			// Continue as before.
