@@ -7,6 +7,7 @@
 
 #include <pthread.h>
 #include <stdio.h>
+#include <mutex>
 #include <string>
 #include <vector>
 
@@ -29,11 +30,11 @@ public:
 private:
 	virtual void do_work();
 
-	// The file we are logging to. If NULL, do not log.
+	// The file we are logging to. If nullptr, do not log.
 	FILE *logfp;
 	std::string filename;
 
-	pthread_mutex_t mutex;
+	std::mutex mu;
 	std::vector<ClientStats> pending_writes;
 };
 
