@@ -431,7 +431,7 @@ bool parse_stream(const ConfigLine &line, Config *config)
 			return false;
 		}
 		stream.hls_backlog_margin = stoi(hls_backlog_margin_it->second);
-		if (stream.hls_backlog_margin < 0 || stream.hls_backlog_margin >= stream.backlog_size) {
+		if (stream.hls_backlog_margin >= stream.backlog_size) {
 			log(ERROR, "'hls_backlog_margin' must be nonnegative, but less than the backlog size");
 			return false;
 		}
