@@ -1,5 +1,6 @@
 #include <assert.h>
 #include <errno.h>
+#include <fcntl.h>
 #include <getopt.h>
 #include <limits.h>
 #include <signal.h>
@@ -622,6 +623,9 @@ start:
 	}
 	for (const auto &key_and_input_with_refcount : inputs) {
 		key_and_input_with_refcount.second.input->stop();
+		if (stopped) {
+			key_and_input_with_refcount.second.input->close_socket();
+		}
 	}
 	servers->stop();
 
@@ -661,6 +665,10 @@ start:
 	char buf[16];
 	sprintf(buf, "%d", state_fd);
 
+	// Unset the close-on-exec flag for the state fd.
+	// (This can't leak into a child, since there's only one thread left.)
+	fcntl(state_fd, F_SETFD, 0);
+
 	for ( ;; ) {
 		execlp(argv0_canon, argv0_canon, config_filename_canon, "--state", buf, nullptr);
 		open_logs(config.log_destinations);
