@@ -57,6 +57,9 @@ public:
 	                const std::string &http_header,
 	                const std::string &stream_header);
 
+	// Sets the given stream as unavailable (will always return 503 to new clients).
+	void set_unavailable(int stream_index);
+
 	// Set that the given stream should use the given max pacing rate from now on.
 	// NOTE: This should be set before any clients are connected!
 	void set_pacing_rate(int stream_index, uint32_t pacing_rate);
