@@ -55,6 +55,9 @@ public:
 	                const std::string &stream_header);
 	void add_data(int stream_index, const char *data, size_t bytes, uint16_t metacube_flags, const RationalPTS &pts);
 
+	// Sets the given stream as unavailable on all the servers.
+	void set_unavailable(int stream_index);
+
 	// Sets the max pacing rate for all the servers.
 	void set_pacing_rate(int stream_index, uint32_t pacing_rate);
 
