@@ -1,7 +1,7 @@
 #ifndef _UDPINPUT_H
 #define _UDPINPUT_H 1
 
-#include <pthread.h>
+#include <mutex>
 #include <string>
 #include <vector>
 
@@ -47,7 +47,7 @@ private:
 	char packet_buf[65536];
 
 	// Mutex protecting <stats>.
-	mutable pthread_mutex_t stats_mutex;
+	mutable std::mutex stats_mutex;
 
 	// The current statistics for this connection. Protected by <stats_mutex>.
 	InputStats stats;
